@@ -35,6 +35,7 @@ class Context(object):
         self.ssh_config = op.join(self.envdir, "ssh_config")
         self.dnsfile = op.join(self.envdir, "dnsmasq.d", "hosts")
         self.postinstall_dir = op.join(self.envdir, "postinstall")
+        self.envid_file = op.join(self.envdir, "envid")
         self.state_file = op.join(self.envdir, "state.json")
 
     def assert_valid_env(self):
@@ -192,6 +193,7 @@ def invoke_before_clean(f):
                                            resolve_path=True),
               help='Changes the folder to operate on.')
 @click.option('--docker-host', default="unix://var/run/docker.sock")
+@click.version_option()
 @pass_context
 def cli(ctx, workdir, docker_host):
     """Manage a small OAR developpement cluster with docker."""
