@@ -1,6 +1,8 @@
 import click
+import os.path as op
 from oardocker.cli import pass_context
 from oardocker.utils import touch
+import uuid
 
 
 @click.command('init')
@@ -12,3 +14,7 @@ def cli(ctx, force):
     touch(ctx.dnsfile)
     ctx.log('Initialized oardocker environment in %s',
             click.format_filename(ctx.envdir))
+    if not op.exists(ctx.envid_file) or op.getsize(ctx.envid_file) == 0:
+        identifier = uuid.uuid5(uuid.NAMESPACE_URL, ctx.envid_file)
+        with open(ctx.envid_file, "w+") as fd:
+            fd.write("%s" % identifier)
